package VMOMI::ComputeResourceHostSPBMLicenseInfoHostSPBMLicenseState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
